==> existing_filenames_sanitizer-1.0.0.tar.gz: existing_filenames_sanitizer/README.md <==
# Filename Sanitizer for Drupal

A Drupal module that provides Drush commands to sanitize existing filenames in your Drupal website. This is useful when you've enabled Drupal's core filename sanitization feature but have existing files that weren't sanitized when they were uploaded.

## Features

- Bulk sanitization of existing file filenames
- Configurable sanitization options
- Dry-run mode to preview changes
- Progress tracking and error reporting
- Safe file renaming with conflict detection
- Support for skipping temporary files
- Handles missing physical files gracefully

## Installation

1. Enable the module: `drush en existing_filenames_sanitizer -y`
3. Clear the cache: `drush cr`

## Usage

### Step 1: Preview Changes (Recommended)

Before making any changes, run a dry-run to see what would be changed:

```bash
drush filename-sanitizer:sanitize-filenames --dry-run
```

This will show you:
- All files that would be renamed
- The original and new filenames
- A summary of changes without actually making them

### Step 3: Apply Changes

Once you're satisfied with the preview, run the command without `--dry-run`:

```bash
drush filename-sanitizer:sanitize-filenames
```

### Custom Options

You can customize the sanitization behavior using command options:

```bash
# Use underscore instead of hyphen
drush filename-sanitizer:sanitize-filenames --replacement-character=_

# Only apply specific sanitization rules
drush filename-sanitizer:sanitize-filenames --transliterate --lowercase

# Combine multiple options
drush filename-sanitizer:sanitize-filenames --transliterate --replace-whitespace --lowercase --replacement-character=_

# Skip temporary files
drush filename-sanitizer:sanitize-filenames --skip-temporary

# Skip files where physical file doesn't exist
drush filename-sanitizer:sanitize-filenames --skip-missing
```

## Available Options

- `--dry-run`: Show what would be changed without making changes
- `--transliterate`: Apply transliteration to filenames
- `--replace-whitespace`: Replace whitespace with replacement character
- `--replace-non-alphanumeric`: Replace non-alphanumeric characters
- `--deduplicate-separators`: Remove duplicate separators
- `--lowercase`: Convert filenames to lowercase
- `--replacement-character`: Character to use for replacements (default: '-')
- `--skip-temporary`: Skip temporary files during sanitization
- `--skip-missing`: Skip files where physical file doesn't exist

## Examples

### Example 1: Basic Usage
```bash
# Preview changes
drush filename-sanitizer:sanitize-filenames --dry-run

# Apply changes
drush filename-sanitizer:sanitize-filenames
```

### Example 2: Custom Settings
```bash
# Use underscore and only transliterate and lowercase
drush filename-sanitizer:sanitize-filenames --transliterate --lowercase --replacement-character=_ --dry-run
```

### Example 3: Aggressive Sanitization
```bash
# Apply all sanitization rules with underscore
drush filename-sanitizer:sanitize-filenames --transliterate --replace-whitespace --replace-non-alphanumeric --deduplicate-separators --lowercase --replacement-character=_
```

### Example 4: Skip Temporary Files
```bash
# Skip temporary files to avoid errors
drush filename-sanitizer:sanitize-filenames --skip-temporary --dry-run
```

### Example 5: Skip Missing Files
```bash
# Skip files where physical file doesn't exist
drush filename-sanitizer:sanitize-filenames --skip-missing --dry-run
```

## What Gets Sanitized

The command processes all permanent files (status = 1) in your Drupal installation. Examples of filename transformations:

- `My Document.pdf` → `my-document.pdf`
- `Résumé.docx` → `resume.docx`
- `File with spaces & symbols!.jpg` → `file-with-spaces-symbols.jpg`
- `UPPERCASE_FILE.PNG` → `uppercase-file.png`

## Safety Features

- **Dry-run mode**: Always preview changes before applying
- **Conflict detection**: Won't overwrite existing files
- **Error handling**: Continues processing even if individual files fail
- **Progress tracking**: Shows progress every 100 files
- **Detailed logging**: Reports all changes and errors
- **Temporary file handling**: Can skip or handle temporary files gracefully
- **Missing file handling**: Handles cases where physical files don't exist
- **Generated content handling**: Special handling for oEmbed thumbnails and cache files

## Troubleshooting

### Common Issues

1. **Permission errors**: Ensure the web server has write permissions to the files directory
2. **File conflicts**: The command will skip files that would conflict with existing files
3. **Memory issues**: For large numbers of files, consider processing in batches
4. **Temporary file errors**: Use `--skip-temporary` to avoid issues with temporary files
5. **Missing file errors**: Use `--skip-missing` to avoid issues with missing physical files

### Checking Results

After running the command, you can verify the changes:

```bash
# Check the files admin page in Drupal
drush uli

# Or use the files view
drush filename-sanitizer:sanitize-filenames --dry-run
```

## Configuration

The sanitization settings are stored in the `file.settings` configuration. You can modify them through:

1. **Admin interface**: `/admin/config/media/file-system`
2. **Configuration export/import**: `drush cex` and `drush cim`
3. **Direct configuration editing**: `drush config:edit file.settings`

## Drush Aliases

The module provides a short alias for the main command:
- `fssf` = `filename-sanitizer:sanitize-filenames`

## Support

If you encounter issues:

1. Check the Drush output for error messages
2. Verify file permissions
3. Ensure the module is properly installed and cached is cleared
4. Test with a small subset of files first using `--dry-run`
5. Use `--skip-temporary` if you encounter temporary file issues
6. Use `--skip-missing` if you encounter missing file issues

## Requirements

- Drupal 10 or 11
- Drush 10 or later
- File module enabled

==> existing_filenames_sanitizer-1.0.1.tar.gz: existing_filenames_sanitizer/README.md <==
# Filename Sanitizer for Drupal

A Drupal module that provides Drush commands to sanitize existing filenames in your Drupal website. This is useful when you've enabled Drupal's core filename sanitization feature but have existing files that weren't sanitized when they were uploaded.

## Features

- Bulk sanitization of existing file filenames
- Configurable sanitization options
- Dry-run mode to preview changes
- Progress tracking and error reporting
- Safe file renaming with conflict detection
- Support for skipping temporary files
- Handles missing physical files gracefully

## Installation

1. Enable the module: `drush en existing_filenames_sanitizer -y`
3. Clear the cache: `drush cr`

## Usage

### Step 1: Preview Changes (Recommended)

Before making any changes, run a dry-run to see what would be changed:

```bash
drush existing-filenames-sanitizer:sanitize-filenames --dry-run
```

This will show you:
- All files that would be renamed
- The original and new filenames
- A summary of changes without actually making them

### Step 2: Apply Changes

Once you're satisfied with the preview, run the command without `--dry-run`:

```bash
drush existing-filenames-sanitizer:sanitize-filenames
```

### Custom Options

You can customize the sanitization behavior using command options:

```bash
# Use underscore instead of hyphen
drush existing-filenames-sanitizer:sanitize-filenames --replacement-character=_

# Only apply specific sanitization rules
drush existing-filenames-sanitizer:sanitize-filenames --transliterate --lowercase

# Combine multiple options
drush existing-filenames-sanitizer:sanitize-filenames --transliterate --replace-whitespace --lowercase --replacement-character=_

# Skip temporary files
drush existing-filenames-sanitizer:sanitize-filenames --skip-temporary

# Skip files where physical file doesn't exist
drush existing-filenames-sanitizer:sanitize-filenames --skip-missing
```

## Available Options

- `--dry-run`: Show what would be changed without making changes
- `--transliterate`: Apply transliteration to filenames
- `--replace-whitespace`: Replace whitespace with replacement character
- `--replace-non-alphanumeric`: Replace non-alphanumeric characters
- `--deduplicate-separators`: Remove duplicate separators
- `--lowercase`: Convert filenames to lowercase
- `--replacement-character`: Character to use for replacements (default: '-')
- `--skip-temporary`: Skip temporary files during sanitization
- `--skip-missing`: Skip files where physical file doesn't exist

## Examples

### Example 1: Basic Usage
```bash
# Preview changes
drush existing-filenames-sanitizer:sanitize-filenames --dry-run

# Apply changes
drush existing-filenames-sanitizer:sanitize-filenames
```

### Example 2: Custom Settings
```bash
# Use underscore and only transliterate and lowercase
drush existing-filenames-sanitizer:sanitize-filenames --transliterate --lowercase --replacement-character=_ --dry-run
```

### Example 3: Aggressive Sanitization
```bash
# Apply all sanitization rules with underscore
drush existing-filenames-sanitizer:sanitize-filenames --transliterate --replace-whitespace --replace-non-alphanumeric --deduplicate-separators --lowercase --replacement-character=_
```

### Example 4: Skip Temporary Files
```bash
# Skip temporary files to avoid errors
drush existing-filenames-sanitizer:sanitize-filenames --skip-temporary --dry-run
```

### Example 5: Skip Missing Files
```bash
# Skip files where physical file doesn't exist
drush existing-filenames-sanitizer:sanitize-filenames --skip-missing --dry-run
```

## What Gets Sanitized

The command processes all permanent files (status = 1) in your Drupal installation. Examples of filename transformations:

- `My Document.pdf` → `my-document.pdf`
- `Résumé.docx` → `resume.docx`
- `File with spaces & symbols!.jpg` → `file-with-spaces-symbols.jpg`
- `UPPERCASE_FILE.PNG` → `uppercase-file.png`

## Safety Features

- **Dry-run mode**: Always preview changes before applying
- **Conflict detection**: Won't overwrite existing files
- **Error handling**: Continues processing even if individual files fail
- **Progress tracking**: Shows progress every 100 files
- **Detailed logging**: Reports all changes and errors
- **Temporary file handling**: Can skip or handle temporary files gracefully
- **Missing file handling**: Handles cases where physical files don't exist
- **Generated content handling**: Special handling for oEmbed thumbnails and cache files

## Troubleshooting

### Common Issues

1. **Permission errors**: Ensure the web server has write permissions to the files directory
2. **File conflicts**: The command will skip files that would conflict with existing files
3. **Memory issues**: For large numbers of files, consider processing in batches
4. **Temporary file errors**: Use `--skip-temporary` to avoid issues with temporary files
5. **Missing file errors**: Use `--skip-missing` to avoid issues with missing physical files

### Checking Results

After running the command, you can verify the changes:

```bash
# Check the files admin page in Drupal
drush uli

# Or use the files view
drush existing-filenames-sanitizer:sanitize-filenames --dry-run
```

## Configuration

The sanitization settings are stored in the `file.settings` configuration. You can modify them through:

1. **Admin interface**: `/admin/config/media/file-system`
2. **Configuration export/import**: `drush cex` and `drush cim`
3. **Direct configuration editing**: `drush config:edit file.settings`

## Drush Aliases

The module provides a short alias for the main command:
- `efssf` = `existing-filenames-sanitizer:sanitize-filenames`

## Support

If you encounter issues:

1. Check the Drush output for error messages
2. Verify file permissions
3. Ensure the module is properly installed and cached is cleared
4. Test with a small subset of files first using `--dry-run`
5. Use `--skip-temporary` if you encounter temporary file issues
6. Use `--skip-missing` if you encounter missing file issues

## Requirements

- Drupal 10 or 11
- Drush 10 or later
- File module enabled
